@@ -5,23 +5,15 @@ use Carp 'croak';
 use Test2::API 'context';
 use Time::Piece;
 
-our $VERSION = '0.03_4';
+our $VERSION = 0.01;
 our @EXPORT = qw(skip_until skip_all_until);
 use base 'Exporter';
 
-sub skip_until($;$$) {
-  my ($why, $count, $datetime) = @_;
+sub skip_until($$$) {
+  my ($why, $num, $datetime) = @_;
 
   check_why($why);
-
-  # count is optional
-  if (@_ == 3) {
-    check_skip_count($count);
-  }
-  else {
-    $datetime = $count;
-    $count = 1;
-  }
+  check_skip_count($num);
 
   my $timepiece = parse_datetime($datetime);
   $timepiece = apply_offset($timepiece);
@@ -29,7 +21,7 @@ sub skip_until($;$$) {
   if (should_skip($timepiece)) {
     # copied from Test2::Tools::Basic::skip
     my $ctx = context();
-    $ctx->skip('skipped test', "$why until $timepiece") for (1..$count);
+    $ctx->skip('skipped test', "$why until $timepiece") for (1..$num);
     $ctx->release;
     no warnings 'exiting';
     last SKIP;
@@ -72,13 +64,13 @@ sub should_skip {
 }
 
 sub check_skip_count {
-  my $count = shift;
-  unless (defined $count &&
-          $count =~ qr/^\d+$/ &&
-          $count > 0)
+  my $num = shift;
+  unless (defined $num &&
+          $num =~ qr/^\d+$/ &&
+          $num > 0)
   {
     croak sprintf('skip test count must be a positive integer! (got %s)',
-      defined $count ? $count : 'undef');
+      defined $num ? $num : 'undef');
   }
   return 1;
 }
@@ -86,10 +78,10 @@ sub check_skip_count {
 sub parse_datetime {
   my $datetime = shift;
 
-  if ($datetime && $datetime =~ qr/^\d\d\d\d-\d\d-\d\dT\d\d:\d\d:\d\d$/) {
+  if ($datetime =~ qr/^\d\d\d\d-\d\d-\d\dT\d\d:\d\d:\d\d$/) {
     return Time::Piece->strptime($datetime, '%Y-%m-%dT%H:%M:%S');
   }
-  elsif ($datetime && $datetime =~ qr/^\d\d\d\d-\d\d-\d\d$/) {
+  elsif ($datetime =~ qr/^\d\d\d\d-\d\d-\d\d$/) {
     return Time::Piece->strptime($datetime, '%Y-%m-%d');
   }
   else {
@@ -115,7 +107,7 @@ Test2::Tools::SkipUntil - skip tests until a date is reached
   use Test2::Tools::SkipUntil;
 
   SKIP: {
-    skip_until "known fail see issue #213", '2018-06-01';
+    skip_until "known fail see issue #213", 3, '2018-06-01';
     ...
   }
 
@@ -126,19 +118,16 @@ Test2::Tools::SkipUntil - skip tests until a date is reached
 =head1 DESCRIPTION
 
 Exports two functions for skipping tests until a datetime is reached. Dates are
-evaluated in C<localtime>. These might be useful when you have known exceptions
-in your test suite which are temporary.
+evaluated in C<localtime>.
 
 =head1 FUNCTIONS
 
-=head2 skip_until ($why, $count, $datetime)
+=head2 skip_until ($why, $num, $datetime)
 
-Skips all tests in a C<SKIP> block, registering C<$count> skipped tests until
-C<localtime> is greater than or equal to C<$datetime>. Just like with
-L<skip|https://metacpan.org/pod/Test2::Tools::Basic#skip($why)>, C<$count> is
-optional, and defaults to 1.
+Skips all tests in a C<SKIP> block, registering C<$num> skipped tests until
+C<localtime> is greater than or equal to C<$datetime>.
 
-C<$datetime> must be a scalar in one of the following formats:
+C<$datetime> must be a scalar string in one of the following formats:
 
 =over 4
 
@@ -155,10 +144,9 @@ C<$datetime> must be a scalar in one of the following formats:
 =head2 skip_all_until ($why, $datetime)
 
 Skips all tests by setting the test plan to zero, and exiting succesfully
-unless C<localtime> is greater than or equal to C<$datetime>. Behaves like
-L<skip_all|https://metacpan.org/pod/Test2::Tools::Basic#skip_all($reason)>.
+unless C<localtime> is greater than or equal to C<$datetime>.
 
-See L</"skip_until ($why, $count, $datetime)"> for the accepted C<$datetime> formats.
+See L<#skip_all> for accepted C<$datetime> formats.
 
 =head1 SOURCE
 
